aboutsummaryrefslogtreecommitdiff
path: root/Minecraft.World/BreedGoal.cpp
diff options
context:
space:
mode:
authorModMaker101 <119018978+ModMaker101@users.noreply.github.com>2026-03-08 19:08:36 -0400
committerGitHub <noreply@github.com>2026-03-08 18:08:36 -0500
commit28614b922fb77149a54da1a87bebfbc98736f296 (patch)
tree7f828ba86a4ee18d0a80d29de64f6199a5412512 /Minecraft.World/BreedGoal.cpp
parent88798b501d0cf6287b6f87acb2592676e3cec58d (diff)
Modernize project codebase (#906)
* Fixed boats falling and a TP glitch #266 * Replaced every C-style cast with C++ ones * Replaced every C-style cast with C++ ones * Fixed boats falling and a TP glitch #266 * Updated NULL to nullptr and fixing some type issues * Modernized and fixed a few bugs - Replaced most instances of `NULL` with `nullptr`. - Replaced most `shared_ptr(new ...)` with `make_shared`. - Removed the `nullptr` macro as it was interfering with the actual nullptr keyword in some instances. * Fixing more conflicts * Replace int loops with size_t and start work on overrides * Add safety checks and fix a issue with vector going OOR
Diffstat (limited to 'Minecraft.World/BreedGoal.cpp')
-rw-r--r--Minecraft.World/BreedGoal.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/Minecraft.World/BreedGoal.cpp b/Minecraft.World/BreedGoal.cpp
index 1c46fd90..10aa6844 100644
--- a/Minecraft.World/BreedGoal.cpp
+++ b/Minecraft.World/BreedGoal.cpp
@@ -25,12 +25,12 @@ bool BreedGoal::canUse()
{
if (!animal->isInLove()) return false;
partner = weak_ptr<Animal>(getFreePartner());
- return partner.lock() != NULL;
+ return partner.lock() != nullptr;
}
bool BreedGoal::canContinueToUse()
{
- return partner.lock() != NULL && partner.lock()->isAlive() && partner.lock()->isInLove() && loveTime < 20 * 3;
+ return partner.lock() != nullptr && partner.lock()->isAlive() && partner.lock()->isInLove() && loveTime < 20 * 3;
}
void BreedGoal::stop()
@@ -74,21 +74,21 @@ void BreedGoal::breed()
shared_ptr<AgableMob> offspring = animal->getBreedOffspring(partner.lock());
animal->setDespawnProtected();
partner.lock()->setDespawnProtected();
- if (offspring == NULL)
+ if (offspring == nullptr)
{
// This will be NULL if we've hit our limits for spawning any particular type of animal... reset things as normally as we can, without actually producing any offspring
animal->resetLove();
partner.lock()->resetLove();
return;
}
shared_ptr<Player> loveCause = animal->getLoveCause();
- if (loveCause == NULL && partner.lock()->getLoveCause() != NULL)
+ if (loveCause == nullptr && partner.lock()->getLoveCause() != nullptr)
{
loveCause = partner.lock()->getLoveCause();
}
- if (loveCause != NULL)
+ if (loveCause != nullptr)
{
// Record mob bred stat.
loveCause->awardStat(GenericStats::breedEntity(offspring->GetType()),GenericStats::param_breedEntity(offspring->GetType()));
@@ -118,5 +118,5 @@ void BreedGoal::breed()
* animal->bbWidth * 2 - animal->bbWidth, xa, ya, za);
}
// 4J-PB - Fix for 106869- Customer Encountered: TU12: Content: Gameplay: Breeding animals does not give any Experience Orbs.
- level->addEntity( shared_ptr<ExperienceOrb>( new ExperienceOrb(level, animal->x, animal->y, animal->z, random->nextInt(7) + 1) ) );
+ level->addEntity(std::make_shared<ExperienceOrb>(level, animal->x, animal->y, animal->z, random->nextInt(7) + 1));
}
@@ -74,21 +74,21 @@ void BreedGoal::breed()
{
- // This will be NULL if we've hit our limits for spawning any particular type of animal... reset things as normally as we can, without actually producing any offspring
+ // This will be nullptr if we've hit our limits for spawning any particular type of animal... reset things as normally as we can, without actually producing any offspring
animal->resetLove();
partner.lock()->resetLove();